"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const smart_buffer_1 = require("smart-buffer");
class SmarterBuffer extends smart_buffer_1.SmartBuffer {
    static fromBuffer(buff, encoding) {
        return new this({ encoding, buff });
    }
    constructor(options) {
        super(options);
    }
    readRect() {
        const nBits = this.readUBits(5);
        const xMin = this.readBits(nBits);
        const xMax = this.readBits(nBits);
        const yMin = this.readBits(nBits);
        const yMax = this.readBits(nBits);
        return { nBits, xMin, xMax, yMin, yMax };
    }
    readFixed(size = 32) {
        let before;
        let after;
        switch (size) {
            case 16:
                after = this.readUInt8();
                before = this.readUInt8();
                break;
            case 32:
            default:
                after = this.readUInt16LE();
                before = this.readUInt16LE();
                break;
        }
        return before + after / Math.pow(2, size / 2);
    }
    readUBits(n) {
        let r = 0;
        while (n > 0) {
            if (this.lastByteCache == null ||
                this.lastByteCacheBitOffset === 8 ||
                this.lastByteCacheOffset < this.readOffset - 1) {
                this.lastByteCacheOffset = this.readOffset;
                this.lastByteCache = this.readUInt8();
                this.lastByteCacheBitOffset = 0;
            }
            const bitsInCache = 8 - this.lastByteCacheBitOffset;
            const x = Math.min(bitsInCache, n);
            r =
                (r << x) |
                    ((this.lastByteCache >> (bitsInCache - x)) & (Math.pow(2, x) - 1));
            this.lastByteCacheBitOffset += x;
            n -= x;
        }
        return r;
    }
    readBits(n) {
        let value = this.readUBits(n);
        const sign = (value >> (n - 1)) & 0x1;
        if (sign === 1) {
            value = value | (0xffffffff << n);
        }
        return value;
    }
    readEncodedU32() {
        let result = this.readInt8();
        if (!(result & 0x00000080)) {
            return result;
        }
        result = (result & 0x0000007f) | (this.readInt8() << 7);
        if (!(result & 0x00004000)) {
            return result;
        }
        result = (result & 0x00003fff) | (this.readInt8() << 14);
        if (!(result & 0x00200000)) {
            return result;
        }
        result = (result & 0x001fffff) | (this.readInt8() << 21);
        if (!(result & 0x10000000)) {
            return result;
        }
        result = (result & 0x0fffffff) | (this.readInt8() << 28);
        return result;
    }
    readS24() {
        const bytes = [this.readUInt8(), this.readUInt8(), this.readUInt8()];
        let val = bytes[0] | (bytes[1] << 8) | (bytes[2] << 16);
        if (val >> 23 !== 0) {
            val = val | 0xff000000;
        }
        return val;
    }
    readEncodedU30() {
        return this.readEncodedU32() & 0x3fffffff;
    }
}
exports.default = SmarterBuffer;
