import { INamespaceInfo } from "./namespace";
export declare enum ConstantKind {
    Int = 3,
    UInt = 4,
    Double = 6,
    Utf8 = 1,
    True = 11,
    False = 10,
    Null = 12,
    Undefined = 0,
    Namespace = 8,
    PackageNamespace = 22,
    PackageInternalNs = 23,
    ProtectedNamespace = 24,
    ExplicitNamespace = 25,
    StaticProtectedNs = 26,
    PrivateNs = 5
}
export interface IConstant {
    kind: ConstantKind;
    val: number | true | false | string | null | undefined | INamespaceInfo;
}
export interface INumberConstant extends IConstant {
    kind: ConstantKind.Int | ConstantKind.UInt | ConstantKind.Double;
    val: number;
}
export interface IUtf8Constant extends IConstant {
    kind: ConstantKind.Utf8;
    val: string;
}
export interface ITrueConstant extends IConstant {
    kind: ConstantKind.True;
    val: true;
}
export interface IFalseConstant extends IConstant {
    kind: ConstantKind.False;
    val: false;
}
export interface INullConstant extends IConstant {
    kind: ConstantKind.Null;
    val: null;
}
export interface IUndefinedConstant extends IConstant {
    kind: ConstantKind.Undefined;
    val: undefined;
}
export interface INamespaceConstant extends IConstant {
    kind: ConstantKind.PackageNamespace | ConstantKind.PackageInternalNs | ConstantKind.ProtectedNamespace | ConstantKind.ExplicitNamespace | ConstantKind.StaticProtectedNs | ConstantKind.PrivateNs | ConstantKind.Namespace;
    val: INamespaceInfo;
}
export declare type Constant = INumberConstant | IUtf8Constant | ITrueConstant | IFalseConstant | INullConstant | IUndefinedConstant | INamespaceConstant;
